import math
import pandas as pd
import xgboost as xgb
from matplotlib import pyplot
from sklearn.metrics import mean_absolute_error, mean_squared_error
from sklearn.model_selection import train_test_split


dataframe = df = pd.read_csv('./data/FULL_RESULTAT_ferdig.csv', sep=',')

data = dataframe.values
# split data into input and output columns
X = data[:, :3]


for i in range(3, 12+3):
    print('processing prediction {:2d} prediction'.format(i-2))
    y = data[:, i]

    # XGBoost training
    X_train, X_test, y_train, y_test = train_test_split(X, y,
                                                        test_size=0.2,
                                                        random_state=0)

    model = xgb.XGBRegressor(n_estimators=600,
                             learning_rate=0.05,
                             min_child_weight=5,
                             eval_metric='rmse',
                             max_depth=5)

    model.fit(X_train, y_train)

    y_pred = model.predict(X_test)

    mae = mean_absolute_error(y_test, y_pred)
    mse = mean_squared_error(y_test, y_pred)

    print("Force: {:2d}, MAE: {:.2f}".format(i-2, mae))
    print("Force: {:2d}, RMSE: {:.2f}".format(i-2, math.sqrt(mse)))

    df = pd.DataFrame(columns=['True', 'Prediction'])
    df['True'] = y_test
    df['Prediction'] = y_pred

    file_saving = 'pred_true_forces_' + str(i-2) + '.csv'

    df.to_csv(file_saving, index=False)

